referrerpolicy=no-referrer-when-downgrade

GrandpaJustificationStream

Type Alias GrandpaJustificationStream 

pub type GrandpaJustificationStream<Block> = NotificationStream<GrandpaJustification<Block>, GrandpaJustificationsTracingKey>;
The receiving half of the Grandpa justification channel.

Used to receive notifications about justifications generated at the end of a Grandpa round. The GrandpaJustificationStream entity stores the SharedJustificationSenders so it can be used to add more subscriptions.

Aliased Type

pub struct GrandpaJustificationStream<Block> { /* private fields */ }